<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Pen
 */

$content_id = pen_post_id();

ob_start();
?><!doctype html>
<html <?php language_attributes(); ?> class="no-js">
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
<?php
wp_head();
?>
	</head>
	<body <?php body_class(); ?>>
		<div id="page" class="site">
			<div class="pen_loading clearfix" role="alert">
				<div class="pen_icon">
				</div>
				<div class="pen_text">
<?php
esc_html_e( 'Loading...', 'pen' );
?>
				</div>
			</div>
			<div class="pen_wrapper">
<?php
if ( ! is_customize_preview() ) {
	pen_html_jump_menu( 'color_schemes', $content_id );
	pen_html_jump_menu( 'font_presets', $content_id );
}
?>
				<a class="screen-reader-shortcut screen-reader-text" href="#content">
<?php
esc_html_e( 'Skip to content', 'pen' );
?>
				</a>
<?php
$header_primary = false;
if ( pen_sidebar_check( 'sidebar-header-primary', $content_id ) && is_active_sidebar( 'sidebar-header-primary' ) ) {
	$header_primary = true;
}
$header_secondary = false;
if ( pen_sidebar_check( 'sidebar-header-secondary', $content_id ) && is_active_sidebar( 'sidebar-header-secondary' ) ) {
	$header_secondary = true;
}
$connect         = pen_html_connect( 'header' );
$connect_display = 'hide';
if ( $connect ) {
	$connect_display = 'show';
}
$search_html     = pen_html_search_box( $content_id );
$search_location = '';
$search_display  = 'hide';
$search_location = get_post_meta( $content_id, 'pen_content_search_location_override', true );
if ( ! $search_location || 'default' === $search_location ) {
	$search_location = pen_option_get( 'search_location' );
}
if ( $search_html ) {
	if ( 'header' === $search_location ) {
		$search_display = 'show';
	} elseif ( 'content' === $search_location ) {
		$search_display = 'show_toolbar';
	}
}
$logo          = pen_html_logo();
$phone         = pen_option_get( 'phone' );
$phone_display = ( $phone && pen_option_get( 'phone_header_display' ) ) ? 'show' : 'hide';

ob_start();
get_template_part( 'partials/site', 'navigation' );
$navigation = trim( ob_get_clean() );

$classes_header = array(
	'site-header',
	$logo ? 'pen_has_logo' : '',
	'pen_phone_' . sanitize_html_class( $phone_display ),
	'pen_connect_' . sanitize_html_class( $connect_display ),
	'pen_search_' . sanitize_html_class( $search_display ),
	'pen_navigation_' . ( $navigation ? 'show' : 'hide' ), // <body> may also get .pen_navigation_hide per content (never the .pen_navigation_show).
	'pen_navigation_mobile_' . ( pen_option_get( 'navigation_mobile_display' ) ? 'show' : 'hide' ),
);

$classes_header = trim( implode( ' ', array_filter( $classes_header ) ) );
?>
				<header id="pen_header" class="<?php echo esc_attr( $classes_header ); ?>" role="banner">
					<div class="pen_header_inner">
<?php
$header_display = get_post_meta( $content_id, 'pen_site_header_display_override', true );
if ( ! $header_display || 'default' === $header_display ) {
	$header_display = pen_option_get( 'site_header_display' );
}
if ( $header_display && 'no' !== $header_display ) {
	$header_display = true;
} else {
	$header_display = false;
}
?>
						<div class="pen_header_main<?php echo ( ! $header_display ) ? ' pen_element_hidden' : ''; ?>">
							<div class="pen_container clearfix">
								<h1>
<?php
echo $logo; /* phpcs:ignore */

get_template_part( 'partials/site', 'title' );
?>
								</h1>
<?php
if ( $header_primary || $header_secondary || 'show' === $phone_display || $connect || ( 'header' === $search_location && $search_html ) ) {
	?>
								<div class="pen_header_wrap pen_animate_on_scroll pen_custom_animation_fadeIn">
	<?php
	pen_sidebar_get( 'sidebar-header-primary', $content_id );

	if ( 'show' === $phone_display ) {
		?>
									<div class="pen_phone <?php pen_class_animation( 'phone_header' ); /* phpcs:ignore */ ?>">
										<a href="tel:<?php echo esc_attr( $phone ); ?>">
		<?php
		echo esc_html( $phone );
		?>
										</a>
									</div>
		<?php
	}

	echo $connect; /* phpcs:ignore */

	if ( 'header' === $search_location ) {
		echo $search_html; /* phpcs:ignore */
	}

	pen_sidebar_get( 'sidebar-header-secondary', $content_id );
	?>
								</div>
	<?php
}
?>
							</div>
<?php
pen_html_jump_menu( 'header', $content_id );
?>
						</div>
<?php
// Adds the main navigation menu.
echo $navigation; /* phpcs:ignore */
?>
					</div><!-- .pen_header_inner -->
<?php
if ( $search_html && 'content' === $search_location ) {
	?>
					<div id="pen_search">
						<div class="pen_container">
	<?php
	pen_sidebar_get( 'sidebar-search-top', $content_id );
	?>
						</div>
						<div class="pen_container">
	<?php
	pen_sidebar_get( 'sidebar-search-left', $content_id );
	?>
							<div id="pen_search_form">
	<?php
	echo $search_html; /* phpcs:ignore */
	?>
							</div>
	<?php
	pen_sidebar_get( 'sidebar-search-right', $content_id );
	?>
						</div>
						<div class="pen_container">
	<?php
	pen_sidebar_get( 'sidebar-search-bottom', $content_id );

	pen_html_jump_menu( 'search_bar', $content_id );
	?>
						</div>
					</div>
	<?php
}
?>
				</header>
				<div id="pen_section">
<?php
pen_sidebar_get( 'sidebar-top', $content_id );
?>
					<div class="pen_container">
						<div id="content" class="site-content clearfix">
